@@ -121,7 +121,7 @@ class Gateway():
                         _LOGGER.exception ("error communicating...: " + str(e1))
         
 
-    def executeCommand(self, command):
+    async def executeCommand(self, command):
         a = CommeoServiceGetState()
         self._executeCommand(a)
         _LOGGER.debug("Service State: " + str(a.status))
@@ -313,7 +313,7 @@ class Gateway():
             _LOGGER.info(str(device))
            
     ## Common ##
-    def pingGateway(self):
+    async def pingGateway(self):
         command = CommeoServicePing()
         command.execute(self)
         print("Ping")
